pub struct TeraHandler(/* private fields */);Expand description
A trillium handler for the Tera template engine
Implementations
Sourceimpl TeraHandler
impl TeraHandler
Sourcepub fn new(tera: impl Into<Self>) -> Self
pub fn new(tera: impl Into<Self>) -> Self
Construct a new TeraHandler from either a &str or PathBuf that represents
a directory glob containing templates, or from a
tera::Tera instance
use std::{iter::FromIterator, path::PathBuf};
use trillium_tera::TeraHandler;
let handler = TeraHandler::new(PathBuf::from_iter([".", "examples", "**", "*.html"]));
// or
let handler = TeraHandler::new("examples/*.html");
// or
let mut tera = trillium_tera::Tera::default();
tera.add_raw_template("hello.html", "hello {{name}}")?;
let handler = TeraHandler::new(tera);Trait Implementations
Sourceimpl Clone for TeraHandler
impl Clone for TeraHandler
Sourcefn clone(&self) -> TeraHandler
fn clone(&self) -> TeraHandler
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TeraHandler
impl Debug for TeraHandler
Sourceimpl From<&[&str]> for TeraHandler
impl From<&[&str]> for TeraHandler
Sourceimpl From<&String> for TeraHandler
impl From<&String> for TeraHandler
Sourceimpl From<&str> for TeraHandler
impl From<&str> for TeraHandler
Sourceimpl From<PathBuf> for TeraHandler
impl From<PathBuf> for TeraHandler
Sourceimpl From<String> for TeraHandler
impl From<String> for TeraHandler
Sourceimpl From<Tera> for TeraHandler
impl From<Tera> for TeraHandler
Sourceimpl Handler for TeraHandler
impl Handler for TeraHandler
Sourceasync fn run(&self, conn: Conn) -> Conn
async fn run(&self, conn: Conn) -> Conn
Executes this handler, performing any modifications to the Conn that are desired.
Sourcefn init(&mut self, info: &mut Info) -> impl Future<Output = ()> + Send
fn init(&mut self, info: &mut Info) -> impl Future<Output = ()> + Send
Performs one-time async set up on a mutable borrow of the Handler before the server starts
accepting requests. This allows a Handler to be defined in synchronous code but perform
async setup such as establishing a database connection or fetching some state from an
external source. This is optional, and chances are high that you do not need this. Read more
Sourcefn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
fn before_send(&self, conn: Conn) -> impl Future<Output = Conn> + Send
Performs any final modifications to this conn after all handlers have been run. Although
this is a slight deviation from the simple conn->conn->conn chain represented by most
Handlers, it provides an easy way for libraries to effectively inject a second handler into
a response chain. This is useful for loggers that need to record information both before and
after other handlers have run, as well as database transaction handlers and similar library
code. Read more
Sourcefn has_upgrade(&self, upgrade: &Upgrade) -> bool
fn has_upgrade(&self, upgrade: &Upgrade) -> bool
predicate function answering the question of whether this Handler would like to take
ownership of the negotiated Upgrade. If this returns true, you must implement
Handler::upgrade. The first handler that responds true to this will receive
ownership of the trillium::Upgrade in a subsequent call to
Handler::upgradeSourcefn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
fn upgrade(&self, upgrade: Upgrade) -> impl Future<Output = ()> + Send
This will only be called if the handler reponds true to
Handler::has_upgrade and will
only be called once for this upgrade. There is no return value, and this function takes
exclusive ownership of the underlying transport once this is called. You can downcast
the transport to whatever the source transport type is and perform any non-http protocol
communication that has been negotiated. You probably don’t want this unless you’re
implementing something like websockets. Please note that for many transports such as
TcpStreams, dropping the transport (and therefore the Upgrade) will hang up /
disconnect.Auto Trait Implementations
impl Freeze for TeraHandler
impl !RefUnwindSafe for TeraHandler
impl Send for TeraHandler
impl Sync for TeraHandler
impl Unpin for TeraHandler
impl UnsafeUnpin for TeraHandler
impl !UnwindSafe for TeraHandler